ResolverOption

Enum ResolverOption 

#[repr(u32)]
pub enum ResolverOption {
Show 18 variants Init = 1, Debug = 2, UseVC = 8, IgnTc = 32, Recurse = 64, DefNames = 128, StayOpen = 256, DNSrch = 512, NoAliases = 4_096, Rotate = 16_384, UseEDNS0 = 1_048_576, SngLkup = 2_097_152, SngLkupReop = 4_194_304, UseDNSSEC = 8_388_608, NoTLDQuery = 16_777_216, NoReload = 33_554_432, TrustAD = 67_108_864, Default = 704,
}
Options for the Resolver

Variants



Init = 1

address initialized



Debug = 2

print debug messages



UseVC = 8

use virtual circuit



IgnTc = 32

ignore truncation errors



Recurse = 64

recursion desired



DefNames = 128

use default domain name



StayOpen = 256

Keep TCP socket open



DNSrch = 512

search up local domain tree



NoAliases = 4_096

shuts off HOSTALIASES feature



Rotate = 16_384

rotate ns list after each query



UseEDNS0 = 1_048_576

Use EDNS0.



SngLkup = 2_097_152

one outstanding request at a time



SngLkupReop = 4_194_304

one outstanding request at a time, but open new socket for each request



UseDNSSEC = 8_388_608

use DNSSEC using OK bit in OPT



NoTLDQuery = 16_777_216

Do not look up unqualified name as a TLD.



NoReload = 33_554_432

No automatic configuration reload (since glibc 2.26; invalid in prior versions)



TrustAD = 67_108_864

Request AD bit, keep it in responses (since glibc 2.31; invalid in prior version)



Default = 704

Default values